Learn R Programming

giphyr (version 0.2.0)

gif_search: Search GIFs by key words throught giphy API

Description

Search GIFs by key words throught giphy API

Usage

gif_search(query, limit = 10, offset = 0, rating = "g",
  img_format = c("fixed_height", "fixed_height_still",
  "fixed_height_downsampled", "fixed_width", "fixed_width_still",
  "fixed_width_downsampled", "fixed_height_small",
  "fixed_height_small_still", "fixed_width_small",
  "fixed_width_small_still", "downsized", "downsized_still",
  "downsized_large", "downsized_medium", "original", "original_still",
  "preview_gif", "fixed_height_mp4", "fixed_width_mp4",
  "fixed_height_small_mp4", "fixed_width_small_mp4", "original_mp4",
  "looping_mp4", "preview_mp4", "downsized_small_mp4"))

Arguments

query

search query term or phrase.

limit

(optional) number of results to return, maximum 100. Default 10.

offset

(optional) results offset, defaults to 0.

rating

limit results to those rated (y,g, pg, pg-13 or r). Default g.

img_format

A vector of strings deciding what formats of images you want to receive. Possible options include "fixed_height", "fixed_height_still", "fixed_height_downsampled", "fixed_width", "fixed_width_still", "fixed_width_downsampled", "fixed_height_small", "fixed_height_small_still", "fixed_width_small", "fixed_width_small_still", "downsized", "downsized_still", "downsized_large", "downsized_medium", "original", "original_still", "preview_gif", "fixed_height_mp4", "fixed_width_mp4", "fixed_height_small_mp4", "fixed_width_small_mp4", "original_mp4", "looping_mp4", "preview_mp4" & "downsized_small_mp4". An Image with fixed height or width has a fixed length of the edge at 200px. A small fixed height or width images has a 100px-long fixed edge. "Downsampled" images are compressed and are good for preview. "Still" images is not a GIF and will not be animated.

Examples

Run this code
# NOT RUN {
gif_search("cat")
gif_search("dog", img_format = "downsized")
gif_search("panda", limit = 100, img_format = "downsized_small_mp4")

# }

Run the code above in your browser using DataLab